@@ -32,7 +32,7 @@ from ..extra_configs import logging_config
 from ..irc import Irc
 
 if TYPE_CHECKING:
-    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription, PubSubPollData
+    from ..pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction, PubSubSubscription, PubSubPollData, PubSubFollow
 
 
 # noinspection PyMethodMayBeStatic
@@ -217,6 +217,13 @@ class BaseBot:
         :param poll: the poll that the triggered the event
         """
 
+    async def on_pubsub_user_follow(self, raw: 'PubSubData', data: 'PubSubFollow'):
+        """
+        triggered when a user follows a channel that is listened to by the bot's pubsub client
+        :param raw: the raw pubsub message
+        :param data: data specific to the user follow
+        """
+
     async def on_bot_shutdown(self):
         """
         triggered when the bot is shutdown
