@@ -67,4 +67,6 @@ class Event(NamedEnum):
     on_pubsub_bits = auto()
     on_pubsub_moderation_action = auto()
     on_pubsub_subscription = auto()
+    on_pubsub_twitch_poll_update = auto()
+    on_pubsub_user_follow = auto()
     on_bot_shutdown = auto()
